@@ -24,7 +24,7 @@ def get_courses() -> List[CourseModel]:
         CourseModel(
             title='Financial Management Lab',
             description="A lab taught as part of a financial management course which focuses on using "
-                        "Excel to solve case problems",
+                        "Excel to solve case problems.",
             highlight_description='Excel skills course',
             periods_taught=['Spring 2014'],
             university=VCU,
