@@ -8,6 +8,7 @@ from derobertis_cv.models.organization import Organization, OrganizationCharacte
 from derobertis_cv.pldata.cover_letters.models import ApplicationTarget, HiringManager, Gender
 from derobertis_cv.pldata.cv import CVModel, ResumeSection
 from derobertis_cv.pldata.employment_model import JobIDs
+from private_cv.contact import get_private_contact_lines
 
 DC_KWARGS = dict(
     location='Washington, DC',
@@ -1281,3 +1282,31 @@ MITRE = Organization(
     ]
 )
 MITRE_TARGET = ApplicationTarget(MITRE, 'Senior Economist')
+
+
+CARBON_HEALTH = Organization(
+    'Carbon Health',
+    'San Francisco, CA',
+    abbreviation='Carbon Health',
+    address_lines=[
+        '55 Pacific Ave',
+        'San Francisco, CA 94111'
+    ],
+    city='San Francisco',
+    characteristics=[
+        OrganizationCharacteristics.WARM_WEATHER,
+        OrganizationCharacteristics.WEST_COAST,
+        OrganizationCharacteristics.LARGE_CITY,
+    ]
+)
+CARBON_HEALTH_TARGET = ApplicationTarget(CARBON_HEALTH, 'Lead Engineer')
+
+
+def carbon_health_cv_modifier(model: CVModel) -> CVModel:
+    model.overview_text = """
+    An entrepreneur, full-stack web engineer and architect, PhD empirical researcher,
+    data scientist, and project manager with a track record of building, deploying, 
+    and managing open- and closed-source applications and research projects.
+    """
+    model.custom_contact_lines_func = get_private_contact_lines
+    return model
