@@ -1,11 +1,11 @@
 import pyexlatex.resume as lr
-from derobertis_cv.pldata.authors import AUTHORS
+from derobertis_cv.pldata.authors import AUTHORS, AuthorExtraTypes
 
 REFERENCE_AUTHOR_KEYS = [
     'andy',
+    'sugata',
     'nimal',
-    'nitish',
-    'sugata'
+    'baolian',
 ]
 
 
@@ -14,7 +14,7 @@ def get_references():
     references = [
         lr.Reference(
             author.name_as_doctor,
-            title_lines=author.title_lines,
+            title_lines=author.title_with_extras([AuthorExtraTypes.CV]),
             company=author.company,
             contact_lines=author.contact_lines,
             email=author.email
