@@ -11,7 +11,8 @@ from derobertis_cv.models.skill_experience import SkillExperience
 from derobertis_cv.models.skill_experiences import SkillExperiences
 from derobertis_cv.pldata.cover_letters.models import SkillFocusPriority, SpecificApplicationFocus, ApplicationFocus
 
-
+PROGRAMMING_BEGIN_DATE: Final[str] = "9/1/2012"
+CF_BEGIN_DATE: Final[str] = "8/1/2016"
 CARBON_BEGIN_DATE: Final[str] = "4/12/2021"
 GRAPHQL_BEGIN_DATE: Final[str] = "12/20/2021"
 
@@ -27,7 +28,7 @@ OTHER = SkillModel('Other', 3)
 
 # Skills
 PROGRAMMING_SKILL = SkillModel(
-    'Programming', 5, experience=SkillExperience('9/1/2012', hours_per_week=30), priority=SkillFocusPriority(5)
+    'Programming', 5, experience=SkillExperience(PROGRAMMING_BEGIN_DATE, hours_per_week=30), priority=SkillFocusPriority(5)
 )
 PRESENTATION_SKILL = SkillModel('presentation', 4, priority=SkillFocusPriority(3))
 COMMUNICATION_SKILL = SkillModel('Communication', 5, parents=(SOFT_SKILLS,))
@@ -43,7 +44,7 @@ ATTENTION_TO_DETAIL_SKILL = SkillModel('attention to detail', 5, parents=(SOFT_S
 SOFTWARE_ARCHITECTURE_SKILL = SkillModel(
     'software architecture', 4, primary_category=PROGRAMMING_SKILL,
     experience=SkillExperiences([
-        SkillExperience('9/1/2012', hours_per_week=4, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(PROGRAMMING_BEGIN_DATE, hours_per_week=4, end_date_inp=CARBON_BEGIN_DATE),
         SkillExperience(CARBON_BEGIN_DATE, hours_per_week=8),
     ]),
     priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5})
@@ -53,7 +54,7 @@ HARDWARE_SKILL = SkillModel('computer hardware', 3, primary_category=OTHER, prio
 SOFTWARE_DEVELOPMENT_SKILL = SkillModel(
     'software development', 5, parents=(PROGRAMMING_SKILL,),
     experience=SkillExperiences([
-        SkillExperience('9/1/2012', hours_per_week=20, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(PROGRAMMING_BEGIN_DATE, hours_per_week=20, end_date_inp=CARBON_BEGIN_DATE),
         SkillExperience(CARBON_BEGIN_DATE, hours_per_week=30),
     ]),
     priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5})
@@ -62,7 +63,7 @@ FRONTEND_SKILL = SkillModel(
     'Front-end Development', 4, parents=(SOFTWARE_DEVELOPMENT_SKILL, SOFTWARE_ARCHITECTURE_SKILL),
     primary_category=PROGRAMMING_SKILL,
     experience=SkillExperiences([
-        SkillExperience('8/1/2016', hours_per_week=5, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CF_BEGIN_DATE, hours_per_week=5, end_date_inp=CARBON_BEGIN_DATE),
         SkillExperience(CARBON_BEGIN_DATE, hours_per_week=10),
     ]),
     priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 4})
@@ -71,7 +72,7 @@ BACKEND_SKILL = SkillModel(
     'Back-end Development', 5, parents=(SOFTWARE_DEVELOPMENT_SKILL, SOFTWARE_ARCHITECTURE_SKILL),
     primary_category=PROGRAMMING_SKILL,
     experience=SkillExperiences([
-        SkillExperience('9/1/2012', hours_per_week=10, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(PROGRAMMING_BEGIN_DATE, hours_per_week=10, end_date_inp=CARBON_BEGIN_DATE),
         SkillExperience(CARBON_BEGIN_DATE, hours_per_week=20),
     ]),
     priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 4})
@@ -84,7 +85,7 @@ CLI_SKILL = SkillModel(
     case_lower_func=first_word_untouched_rest_lower,
     case_title_func=first_word_untouched_rest_title,
     primary_category=PROGRAMMING_SKILL,
-    experience=SkillExperience('8/1/2016', hours_per_week=1),
+    experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=1),
     priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 4})
 )
 DATABASE_SKILL = SkillModel(
@@ -93,17 +94,17 @@ DATABASE_SKILL = SkillModel(
 )
 DEV_OPS_SKILL = SkillModel(
     'Dev-Ops', 4, parents=(PROGRAMMING_SKILL,), primary_category='self',
-    experience=SkillExperience('8/1/2016', hours_per_week=2),
+    experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=2),
     priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 4})
 )
 REMOTE_DEVELOPMENT_SKILL = SkillModel(
     'Remote development', 3, parents=(PROGRAMMING_SKILL,),
-    experience=SkillExperience('8/1/2016', hours_per_week=0.5),
+    experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=0.5),
     priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 4})
 )
 SECURITY_SKILL = SkillModel(
     'Security', 3, parents=(PROGRAMMING_SKILL, SOFTWARE_ARCHITECTURE_SKILL),
-    experience=SkillExperience('8/1/2016', hours_per_week=2),
+    experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=2),
     priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 5})
 )
 WEB_DEVELOPMENT_SKILL = SkillModel(
@@ -112,7 +113,7 @@ WEB_DEVELOPMENT_SKILL = SkillModel(
     parents=(SOFTWARE_DEVELOPMENT_SKILL, SOFTWARE_ARCHITECTURE_SKILL, REMOTE_DEVELOPMENT_SKILL, SECURITY_SKILL),
     primary_category=PROGRAMMING_SKILL,
     experience=SkillExperiences([
-        SkillExperience('8/1/2016', hours_per_week=10, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CF_BEGIN_DATE, hours_per_week=10, end_date_inp=CARBON_BEGIN_DATE),
         SkillExperience(CARBON_BEGIN_DATE, hours_per_week=15),
     ]),
     priority=SkillFocusPriority(4, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 5})
@@ -127,13 +128,13 @@ MOBILE_DEVELOPMENT_SKILL = SkillModel(
 )
 CSS_SKILL = SkillModel(
     'CSS', 4, parents=(WEB_DEVELOPMENT_SKILL, FRONTEND_SKILL), flexible_case=False, primary_category=PRESENTATION_SKILL,
-    experience=SkillExperience('8/1/2016', hours_per_week=1),
+    experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=1),
     priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 4})
 )
 FRAMEWORK_SKILL = SkillModel('Frameworks', 5, parents=(PROGRAMMING_SKILL,))
 DEBUGGING_SKILL = SkillModel(
     'Debugging', 4, parents=(PROGRAMMING_SKILL,),
-    experience=SkillExperience('9/1/2012', hours_per_week=2),
+    experience=SkillExperience(PROGRAMMING_BEGIN_DATE, hours_per_week=2),
     priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 4})
 )
 TESTING_SKILL = SkillModel(
@@ -151,7 +152,7 @@ PARALLELISM_SKILL = SkillModel(
 )
 CRYPTOGRAPHY_SKILL = SkillModel(
     'Cryptography', 3, parents=(PROGRAMMING_SKILL, SECURITY_SKILL),
-    experience=SkillExperience('8/1/2016', hours_per_week=0.15),
+    experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=0.15),
     priority=SkillFocusPriority(
         2,
         {
@@ -180,13 +181,13 @@ EXCEL_SKILL = SkillModel(
 )
 AUTOMATION_SKILL = SkillModel(
     'automation', 5, parents=(PROGRAMMING_SKILL,),
-    experience=SkillExperience('9/1/2012', hours_per_week=2),
+    experience=SkillExperience(PROGRAMMING_BEGIN_DATE, hours_per_week=2),
     priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 4})
 )
 SERVER_ADMIN_SKILL = SkillModel(
     'server administration', 4, parents=(DEV_OPS_SKILL, WEB_DEVELOPMENT_SKILL),
     experience=SkillExperiences([
-        SkillExperience('8/1/2016', hours_per_week=0.5, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CF_BEGIN_DATE, hours_per_week=0.5, end_date_inp=CARBON_BEGIN_DATE),
         SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.1),
     ]),
     priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 4})
@@ -194,19 +195,19 @@ SERVER_ADMIN_SKILL = SkillModel(
 NETWORKING_SKILL = SkillModel(
     'networking', 3, parents=(DEV_OPS_SKILL,),
     experience=SkillExperiences([
-        SkillExperience('8/1/2016', hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CF_BEGIN_DATE, hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
         SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.05),
     ]),
     priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 3})
 )
 MONITORING_SKILL = SkillModel(
     'application monitoring', 2, parents=(DEV_OPS_SKILL,),
-    experience=SkillExperience('8/1/2016', hours_per_week=0.25),
+    experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=0.25),
     priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 3})
 )
 CI_SKILL = SkillModel(
     'CI/CD', 4, parents=(DEV_OPS_SKILL,), flexible_case=False,
-    experience=SkillExperience('8/1/2016', hours_per_week=1),
+    experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=1),
     priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 4})
 )
 SEO_SKILL = SkillModel(
@@ -224,7 +225,7 @@ CMS_SKILL = SkillModel(
 )
 MIGRATIONS_SKILL = SkillModel(
     'migrations', 5, parents=(DATABASE_SKILL,), primary_category=PROGRAMMING_SKILL,
-    experience=SkillExperience('8/1/2016', hours_per_week=0.5),
+    experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=0.5),
     priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 4})
 )
 IDE_SKILL = SkillModel(
@@ -319,12 +320,12 @@ WEB_SCRAPING_SKILL = SkillModel(
 )
 DOCUMENTATION_SKILL = SkillModel(
     'documentation', 4, parents=(PROGRAMMING_SKILL, PRESENTATION_SKILL, TYPE_SETTING_SKILL),
-    experience=SkillExperience('8/1/2016', hours_per_week=1),
+    experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=1),
     priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 4})
 )
 TEMPLATING_SKILL = SkillModel(
     'templating', 5, parents=(PROGRAMMING_SKILL, PRESENTATION_SKILL, TYPE_SETTING_SKILL),
-    experience=SkillExperience('8/1/2016', hours_per_week=1),
+    experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=1),
     priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 4, SpecificApplicationFocus.DATA_SCIENCE: 3})
 )
 
@@ -379,7 +380,7 @@ PYTHON_SKILL = SkillModel(
 JS_SKILL = SkillModel(
     'JavaScript', 4, parents=(PROGRAMMING_SKILL,), flexible_case=False,
     experience=SkillExperiences([
-        SkillExperience('8/1/2016', hours_per_week=4, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CF_BEGIN_DATE, hours_per_week=4, end_date_inp=CARBON_BEGIN_DATE),
         SkillExperience(CARBON_BEGIN_DATE, hours_per_week=15),
     ]),
     priority=SkillFocusPriority(5)
@@ -387,13 +388,18 @@ JS_SKILL = SkillModel(
 TS_SKILL = SkillModel(
     'TypeScript', 4, parents=(JS_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL,
     experience=SkillExperiences([
-        SkillExperience('8/1/2016', hours_per_week=4, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CF_BEGIN_DATE, hours_per_week=4, end_date_inp=CARBON_BEGIN_DATE),
         SkillExperience(CARBON_BEGIN_DATE, hours_per_week=15),
     ]),
     priority=SkillFocusPriority(5)
 )
+JAVA_SKILL = SkillModel(
+    "Java", 2, parents=(PROGRAMMING_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL,
+    experience=SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.5),
+    priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 4}),
+)
 SCALA_SKILL = SkillModel(
-    "Scala", 3, parents=(PROGRAMMING_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL,
+    "Scala", 4, parents=(PROGRAMMING_SKILL, JAVA_SKILL), flexible_case=False, primary_category=PROGRAMMING_SKILL,
     experience=SkillExperiences([
         SkillExperience(CARBON_BEGIN_DATE, hours_per_week=10, end_date_inp=GRAPHQL_BEGIN_DATE),
         SkillExperience(GRAPHQL_BEGIN_DATE, hours_per_week=5),
@@ -401,31 +407,27 @@ SCALA_SKILL = SkillModel(
     priority=SkillFocusPriority(5),
 )
 KOTLIN_SKILL = SkillModel(
-    "Kotlin", 1, parents=(PROGRAMMING_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL,
+    "Kotlin", 3, parents=(PROGRAMMING_SKILL, JAVA_SKILL), flexible_case=False, primary_category=PROGRAMMING_SKILL,
     experience=SkillExperiences([
         SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.5, end_date_inp=GRAPHQL_BEGIN_DATE),
         SkillExperience(GRAPHQL_BEGIN_DATE, hours_per_week=5),
     ]),
     priority=SkillFocusPriority(3),
 )
-JAVA_SKILL = SkillModel(
-    "Java", 1, parents=(PROGRAMMING_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL,
-    experience=SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.5),
-    priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 4}),
-)
 AWS_SKILL = SkillModel(
     'AWS', 3, parents=(DEV_OPS_SKILL, WEB_DEVELOPMENT_SKILL, REMOTE_DEVELOPMENT_SKILL), flexible_case=False,
     experience=SkillExperiences([
-        SkillExperience('8/1/2016', hours_per_week=1, end_date_inp=CARBON_BEGIN_DATE),
+        SkillExperience(CF_BEGIN_DATE, hours_per_week=1, end_date_inp=CARBON_BEGIN_DATE),
         SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.2),
     ]),
     priority=SkillFocusPriority(4, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 5})
 )
 
 DS_FRAMEWORK_SKILLS = (FRAMEWORK_SKILL, PYTHON_SKILL, DATA_SCIENCE_SKILL)
-BE_WEB_FRAMEWORK_SKILLS = (FRAMEWORK_SKILL, PYTHON_SKILL, WEB_DEVELOPMENT_SKILL, BACKEND_SKILL)
+BE_PYTHON_WEB_FRAMEWORK_SKILLS = (FRAMEWORK_SKILL, PYTHON_SKILL, WEB_DEVELOPMENT_SKILL, BACKEND_SKILL)
+BE_JAVA_WEB_FRAMEWORK_SKILLS = (FRAMEWORK_SKILL, JAVA_SKILL, WEB_DEVELOPMENT_SKILL, BACKEND_SKILL)
 FE_TS_WEB_FRAMEWORK_SKILLS = (FRAMEWORK_SKILL, TS_SKILL, WEB_DEVELOPMENT_SKILL, FRONTEND_SKILL)
-FULL_STACK_WEB_PYTHON_FRAMEWORK_SKILLS = BE_WEB_FRAMEWORK_SKILLS + (FRONTEND_SKILL,)
+FULL_STACK_WEB_PYTHON_FRAMEWORK_SKILLS = BE_PYTHON_WEB_FRAMEWORK_SKILLS + (FRONTEND_SKILL,)
 WEB_SCRAPING_FRAMEWORK_SKILLS = (FRAMEWORK_SKILL, WEB_SCRAPING_SKILL, PYTHON_SKILL)
 PARSING_FRAMEWORK_SKILLS = (FRAMEWORK_SKILL, PARSING_SKILL, PYTHON_SKILL)
 ASYNC_FRAMEWORK_SKILLS = (FRAMEWORK_SKILL, PYTHON_SKILL, ASYNC_SKILL)
@@ -524,12 +526,12 @@ _SKILLS: List[SkillModel] = [
     ),
     SkillModel(
         'Angular', 4, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False, primary_category=FRAMEWORK_SKILL,
-        experience=SkillExperience('8/1/2016', hours_per_week=3, end_date_inp=CARBON_BEGIN_DATE),
+        experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=3, end_date_inp=CARBON_BEGIN_DATE),
         priority=SkillFocusPriority(4, {SpecificApplicationFocus.TECH_COMPANY: 5})
     ),
     SkillModel(
         'Compodoc', 3, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.1, end_date_inp=CARBON_BEGIN_DATE),
+        experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=0.1, end_date_inp=CARBON_BEGIN_DATE),
         priority=SkillFocusPriority(1, {SpecificApplicationFocus.TECH_COMPANY: 2})
     ),
     SkillModel(
@@ -547,8 +549,11 @@ _SKILLS: List[SkillModel] = [
         priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5})
     ),
     SkillModel(
-        'Storybook', 2, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False,
-        experience=SkillExperience('2/1/2021', one_time_hours=10),
+        'Storybook', 3, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False,
+        experience=SkillExperiences([
+            SkillExperience('2/1/2021', one_time_hours=10, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.5),
+        ]),
         priority=SkillFocusPriority(1, {SpecificApplicationFocus.TECH_COMPANY: 2})
     ),
     SkillModel(
@@ -571,6 +576,11 @@ _SKILLS: List[SkillModel] = [
         experience=SkillExperience(CARBON_BEGIN_DATE, hours_per_week=5),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3})
     ),
+    SkillModel(
+        'ESLint', 3, parents=FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False, primary_category=FRAMEWORK_SKILL,
+        experience=SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.1),
+        priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3})
+    ),
     SkillModel(
         'Qt', 2, parents=(FRAMEWORK_SKILL, FRONTEND_SKILL), flexible_case=False, primary_category=FRAMEWORK_SKILL,
         experience=SkillExperience('2/12/2021', hours_per_week=0, one_time_hours=10),
@@ -578,7 +588,7 @@ _SKILLS: List[SkillModel] = [
     ),
     SkillModel(
         'Docker', 4, parents=(DEV_OPS_SKILL,), flexible_case=False,
-        experience=SkillExperience('8/1/2016', hours_per_week=2),
+        experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=2),
         priority=SkillFocusPriority(5)
     ),
     SkillModel(
@@ -594,7 +604,7 @@ _SKILLS: List[SkillModel] = [
     ),
     SkillModel(
         'Stata', 4, parents=(PROGRAMMING_SKILL,), flexible_case=False,
-        experience=SkillExperience('9/1/2012', hours_per_week=0, one_time_hours=800),
+        experience=SkillExperience(PROGRAMMING_BEGIN_DATE, hours_per_week=0, one_time_hours=800),
         priority=SkillFocusPriority(5)
     ),
     SkillModel(
@@ -609,7 +619,7 @@ _SKILLS: List[SkillModel] = [
     ),
     SkillModel(
         'NoSQL', 2, parents=(DATABASE_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.25),
+        experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=0.25),
         priority=SkillFocusPriority(5)
     ),
     SkillModel(
@@ -619,14 +629,13 @@ _SKILLS: List[SkillModel] = [
     ),
     SkillModel(
         'Bash', 3, parents=(PROGRAMMING_SKILL,), flexible_case=False,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.5),
+        experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=0.5),
         priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 4})
     ),
-
     SkillModel(
         'EC2', 4, parents=(AWS_SKILL, SERVER_ADMIN_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL,
         experience=SkillExperiences([
-            SkillExperience('8/1/2016', hours_per_week=0.5, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CF_BEGIN_DATE, hours_per_week=0.5, end_date_inp=CARBON_BEGIN_DATE),
             SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.1),
         ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
@@ -634,7 +643,7 @@ _SKILLS: List[SkillModel] = [
     SkillModel(
         'RDS', 3, parents=(AWS_SKILL, DATABASE_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL,
         experience=SkillExperiences([
-            SkillExperience('8/1/2016', hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CF_BEGIN_DATE, hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
             SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.1),
         ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
@@ -642,7 +651,7 @@ _SKILLS: List[SkillModel] = [
     SkillModel(
         'VPC', 3, parents=(AWS_SKILL, NETWORKING_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL,
         experience=SkillExperiences([
-            SkillExperience('8/1/2016', hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CF_BEGIN_DATE, hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
             SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.1),
         ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
@@ -650,7 +659,7 @@ _SKILLS: List[SkillModel] = [
     SkillModel(
         'Route53', 3, parents=(AWS_SKILL, NETWORKING_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL,
         experience=SkillExperiences([
-            SkillExperience('8/1/2016', hours_per_week=0.1, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CF_BEGIN_DATE, hours_per_week=0.1, end_date_inp=CARBON_BEGIN_DATE),
             SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.01),
         ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
@@ -658,7 +667,7 @@ _SKILLS: List[SkillModel] = [
     SkillModel(
         'S3', 3, parents=(AWS_SKILL, DATABASE_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL,
         experience=SkillExperiences([
-            SkillExperience('8/1/2016', hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CF_BEGIN_DATE, hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
             SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.1),
         ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
@@ -666,7 +675,7 @@ _SKILLS: List[SkillModel] = [
     SkillModel(
         'ElastiCache', 3, parents=(AWS_SKILL, DATABASE_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL,
         experience=SkillExperiences([
-            SkillExperience('8/1/2016', hours_per_week=0.5, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CF_BEGIN_DATE, hours_per_week=0.5, end_date_inp=CARBON_BEGIN_DATE),
             SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.05),
         ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
@@ -674,7 +683,7 @@ _SKILLS: List[SkillModel] = [
     SkillModel(
         'IAM', 3, parents=(AWS_SKILL, COLLABORATION_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL,
         experience=SkillExperiences([
-            SkillExperience('8/1/2016', hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CF_BEGIN_DATE, hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
             SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.01),
         ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
@@ -682,7 +691,7 @@ _SKILLS: List[SkillModel] = [
     SkillModel(
         'CloudWatch', 3, parents=(AWS_SKILL, MONITORING_SKILL), flexible_case=False, primary_category=DEV_OPS_SKILL,
         experience=SkillExperiences([
-            SkillExperience('8/1/2016', hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CF_BEGIN_DATE, hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
             SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.1),
         ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
@@ -691,7 +700,7 @@ _SKILLS: List[SkillModel] = [
         'CloudFormation', 2, parents=(AWS_SKILL, SERVER_ADMIN_SKILL, NETWORKING_SKILL), flexible_case=False,
         primary_category=DEV_OPS_SKILL,
         experience=SkillExperiences([
-            SkillExperience('8/1/2016', hours_per_week=0.15, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CF_BEGIN_DATE, hours_per_week=0.15, end_date_inp=CARBON_BEGIN_DATE),
             SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.05),
         ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 3})
@@ -716,16 +725,21 @@ _SKILLS: List[SkillModel] = [
 
     SkillModel(
         'Nginx', 3, parents=(SERVER_ADMIN_SKILL,), flexible_case=False, primary_category=DEV_OPS_SKILL,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.25),
+        experience=SkillExperiences([
+            SkillExperience(CF_BEGIN_DATE, hours_per_week=0.25, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.05),
+        ]),
         priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 4})
     ),
 
     SkillModel(
         'JIRA', 4, parents=(WEB_DEVELOPMENT_SKILL, COLLABORATION_SKILL), flexible_case=False, primary_category=OTHER,
-        experience=SkillExperience('8/1/2016', hours_per_week=2, end_date_inp=CARBON_BEGIN_DATE),
+        experience=SkillExperiences([
+            SkillExperience(CF_BEGIN_DATE, hours_per_week=2, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.5),
+        ]),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 4, SpecificApplicationFocus.DATA_SCIENCE: 3})
     ),
-
     SkillModel(
         'PyCharm', 4, parents=(IDE_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL,
         experience=SkillExperiences([
@@ -741,7 +755,7 @@ _SKILLS: List[SkillModel] = [
     ),
     SkillModel(
         'IDEA', 4, parents=(IDE_SKILL,), flexible_case=False, primary_category=PROGRAMMING_SKILL,
-        experience=SkillExperience(CARBON_BEGIN_DATE, hours_per_week=25),
+        experience=SkillExperience(CARBON_BEGIN_DATE, hours_per_week=15),
         priority=SkillFocusPriority(1, {SpecificApplicationFocus.TECH_COMPANY: 3, SpecificApplicationFocus.DATA_SCIENCE: 2})
     ),
 
@@ -770,7 +784,7 @@ _SKILLS: List[SkillModel] = [
     ),
     SkillModel(
         'Gitlab CI', 3, parents=(CI_SKILL,), flexible_case=False, primary_category=DEV_OPS_SKILL,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.5, one_time_hours=75, end_date_inp=CARBON_BEGIN_DATE),
+        experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=0.5, one_time_hours=75, end_date_inp=CARBON_BEGIN_DATE),
         priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 4})
     ),
 
@@ -813,7 +827,7 @@ _SKILLS: List[SkillModel] = [
 
     SkillModel(
         'econometrics', 4, parents=(STATISTICS_SKILL,), primary_category=DATA_SCIENCE_SKILL,
-        experience=SkillExperience('9/1/2012', hours_per_week=2),
+        experience=SkillExperience(PROGRAMMING_BEGIN_DATE, hours_per_week=2),
         priority=SkillFocusPriority(
             4,
             {
@@ -828,13 +842,16 @@ _SKILLS: List[SkillModel] = [
     ),
     SkillModel(
         'Quality assurance', 3, primary_category=OTHER,
-        experience=SkillExperience('2/1/2017', hours_per_week=3),
+        experience=SkillExperiences([
+            SkillExperience('2/1/2017', hours_per_week=3, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=1),
+        ]),
         priority=SkillFocusPriority(1, {SpecificApplicationFocus.TECH_COMPANY: 4})
     ),
     SkillModel(
         'HTML', 4, parents=(WEB_DEVELOPMENT_SKILL, FRONTEND_SKILL, TYPE_SETTING_SKILL), flexible_case=False,
         primary_category=PRESENTATION_SKILL,
-        experience=SkillExperience('8/1/2016', hours_per_week=2),
+        experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=2),
         priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 5, SpecificApplicationFocus.DATA_SCIENCE: 4})
     ),
     SkillModel(
@@ -868,7 +885,7 @@ _SKILLS: List[SkillModel] = [
     ),
     SkillModel(
         'jQuery', 2, parents=(JS_SKILL, FRAMEWORK_SKILL), flexible_case=False, primary_category=FRAMEWORK_SKILL,
-        experience=SkillExperience('8/1/2016', one_time_hours=25),
+        experience=SkillExperience(CF_BEGIN_DATE, one_time_hours=25),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 4, SpecificApplicationFocus.DATA_SCIENCE: 3})
     ),
 
@@ -1028,10 +1045,12 @@ _SKILLS: List[SkillModel] = [
             }
         )
     ),
-
     SkillModel(
-        'Flask', 5, parents=BE_WEB_FRAMEWORK_SKILLS, flexible_case=False,
-        experience=SkillExperience('8/1/2016', hours_per_week=5, end_date_inp=CARBON_BEGIN_DATE),
+        'Flask', 5, parents=BE_PYTHON_WEB_FRAMEWORK_SKILLS, flexible_case=False,
+        experience=SkillExperiences([
+            SkillExperience(CF_BEGIN_DATE, hours_per_week=5, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0),
+        ]),
         priority=SkillFocusPriority(
             4,
             {
@@ -1042,8 +1061,11 @@ _SKILLS: List[SkillModel] = [
         )
     ),
     SkillModel(
-        'Django', 2, parents=BE_WEB_FRAMEWORK_SKILLS, flexible_case=False,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.1, one_time_hours=20),
+        'Django', 2, parents=BE_PYTHON_WEB_FRAMEWORK_SKILLS, flexible_case=False,
+        experience=SkillExperiences([
+            SkillExperience(CF_BEGIN_DATE, hours_per_week=0.1, one_time_hours=20, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0),
+        ]),
         priority=SkillFocusPriority(
             3,
             {
@@ -1054,9 +1076,9 @@ _SKILLS: List[SkillModel] = [
         )
     ),
     SkillModel(
-        'SQLAlchemy', 5, parents=BE_WEB_FRAMEWORK_SKILLS, flexible_case=False,
+        'SQLAlchemy', 5, parents=BE_PYTHON_WEB_FRAMEWORK_SKILLS, flexible_case=False,
         experience=SkillExperiences([
-            SkillExperience('8/1/2016', hours_per_week=5, end_date_inp=CARBON_BEGIN_DATE),
+            SkillExperience(CF_BEGIN_DATE, hours_per_week=5, end_date_inp=CARBON_BEGIN_DATE),
             SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.5),
         ]),
         priority=SkillFocusPriority(
@@ -1069,7 +1091,7 @@ _SKILLS: List[SkillModel] = [
         )
     ),
     SkillModel(
-        'pydantic', 5, parents=BE_WEB_FRAMEWORK_SKILLS, flexible_case=False,
+        'pydantic', 5, parents=BE_PYTHON_WEB_FRAMEWORK_SKILLS, flexible_case=False,
         experience=SkillExperiences([
             SkillExperience('6/1/2019', hours_per_week=1, end_date_inp=CARBON_BEGIN_DATE),
             SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.5),
@@ -1082,7 +1104,7 @@ _SKILLS: List[SkillModel] = [
         )
     ),
     SkillModel(
-        'FastAPI', 3, parents=BE_WEB_FRAMEWORK_SKILLS, flexible_case=False,
+        'FastAPI', 3, parents=BE_PYTHON_WEB_FRAMEWORK_SKILLS, flexible_case=False,
         experience=SkillExperiences([
             SkillExperience('6/1/2020', hours_per_week=3, one_time_hours=30, end_date_inp=CARBON_BEGIN_DATE),
             SkillExperience(CARBON_BEGIN_DATE, hours_per_week=0.5),
@@ -1096,7 +1118,9 @@ _SKILLS: List[SkillModel] = [
         )
     ),
     SkillModel(
-        'GraphQL', 3, parents=BE_WEB_FRAMEWORK_SKILLS + FE_TS_WEB_FRAMEWORK_SKILLS, flexible_case=False,
+        'GraphQL', 3,
+        parents=BE_PYTHON_WEB_FRAMEWORK_SKILLS + FE_TS_WEB_FRAMEWORK_SKILLS + (KOTLIN_SKILL, JAVA_SKILL),
+        flexible_case=False,
         experience=SkillExperience(GRAPHQL_BEGIN_DATE, hours_per_week=10),
         priority=SkillFocusPriority(
             2,
@@ -1106,6 +1130,36 @@ _SKILLS: List[SkillModel] = [
             }
         )
     ),
+    SkillModel(
+        'Spring Boot', 2, parents=BE_JAVA_WEB_FRAMEWORK_SKILLS, flexible_case=False,
+        experience=SkillExperience(GRAPHQL_BEGIN_DATE, hours_per_week=1),
+        priority=SkillFocusPriority(
+            2,
+            {
+                SpecificApplicationFocus.TECH_COMPANY: 4,
+            }
+        )
+    ),
+    SkillModel(
+        'DGS', 3, parents=BE_JAVA_WEB_FRAMEWORK_SKILLS, flexible_case=False,
+        experience=SkillExperience(GRAPHQL_BEGIN_DATE, hours_per_week=4),
+        priority=SkillFocusPriority(
+            2,
+            {
+                SpecificApplicationFocus.TECH_COMPANY: 3,
+            }
+        )
+    ),
+    SkillModel(
+        'Detekt', 2, parents=(FRAMEWORK_SKILL, KOTLIN_SKILL,), flexible_case=False,
+        experience=SkillExperience(GRAPHQL_BEGIN_DATE, hours_per_week=1),
+        priority=SkillFocusPriority(
+            1,
+            {
+                SpecificApplicationFocus.TECH_COMPANY: 2,
+            }
+        )
+    ),
     SkillModel(
         'Celery', 4, parents=ASYNC_FRAMEWORK_SKILLS, flexible_case=False,
         experience=SkillExperiences([
@@ -1115,14 +1169,14 @@ _SKILLS: List[SkillModel] = [
         priority=SkillFocusPriority(3, {SpecificApplicationFocus.TECH_COMPANY: 4})
     ),
     SkillModel(
-        'Uvicorn', 3, parents=BE_WEB_FRAMEWORK_SKILLS + ASYNC_FRAMEWORK_SKILLS, flexible_case=False,
+        'Uvicorn', 3, parents=BE_PYTHON_WEB_FRAMEWORK_SKILLS + ASYNC_FRAMEWORK_SKILLS, flexible_case=False,
         experience=SkillExperience('6/1/2020', hours_per_week=0.1, one_time_hours=10),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3})
     ),
 
     SkillModel(
         'Requests', 4, parents=WEB_SCRAPING_FRAMEWORK_SKILLS, flexible_case=False,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.5),
+        experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=0.5),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3})
     ),
     SkillModel(
@@ -1170,7 +1224,7 @@ _SKILLS: List[SkillModel] = [
 
     SkillModel(
         'Jinja2', 4, parents=(FRAMEWORK_SKILL, PYTHON_SKILL, TEMPLATING_SKILL), flexible_case=False,
-        experience=SkillExperience('8/1/2016', hours_per_week=0.5),
+        experience=SkillExperience(CF_BEGIN_DATE, hours_per_week=0.5),
         priority=SkillFocusPriority(2, {SpecificApplicationFocus.TECH_COMPANY: 3})
     ),
     SkillModel(
