@@ -12,6 +12,9 @@ EXCLUDED_SOFTWARE_PROJECTS = [
     'fin-model-course-projects',
     'awesome-panel',
     'awesome-panel-extensions',
+    'derobertis-consulting',
+    'defi-lending',
+    'py-xbrl',  # too early stage, can remove if developed
 ]
 
 PROFESSIONAL_SOFTWARE_PROJECT_ORDER = [
